import time

from netforce.model import Model,fields,get_model
from netforce.access import get_active_company, set_active_company, get_active_user, set_active_user

class ReportLaborCostDaily(Model):
    _name="clinic.report.labor.cost.daily"
    _string="Report Labor Cost Daily"
    _transient=True
    
    _fields={
        "date": fields.Date("Date"),
        "date_from": fields.Date("From"), # use for generate
        "date_to": fields.Date("To"), # use for generate
        "staff_type": fields.Selection([["doctor","Doctor"],["nurse","Nurse"],["staff","Staff"]],"Type"),
        'staff_id': fields.Many2One("clinic.staff","Staff"),
        'department_id': fields.Many2One("clinic.department",'Department'),
        'branch_id': fields.Many2One("clinic.branch","Branch"),
        'cycle_id': fields.Many2One("clinic.cycle","Cycle"), # use for generate
    }

    def default_get(self,field_names=None,context={},**kw):
        defaults=context.get("defaults",{})
        date=defaults.get('date',time.strftime("%Y-%m-%d"))
        staff_type=defaults.get("staff_type","doctor")
        staff_id=int(defaults.get('staff_id', "0"))
        department_id=int(defaults.get('department_id', "0"))
        branch_id=int(defaults.get('branch_id', "0"))
        res={
            'date': date,
            'staff_type': staff_type,
            'staff_id': staff_id and staff_id or None,
            'department_id': department_id and department_id or None,
            'branch_id': branch_id and branch_id or None,
        }
        print("res ", res)
        return res
    
    def get_report_data(self,ids,context={}):
        company_id=get_active_company()
        user_id=get_active_user()
        if not company_id:
            set_active_company(1)
            company_id=1
        if not user_id:
            set_active_user(1)
            user_id=1

        comp=get_model("company").browse(company_id)
        defaults=self.default_get(context=context)
        date=defaults.get("date")
        staff_id=defaults.get("staff_id")
        staff_type=defaults.get("staff_type")
        branch_id=defaults.get("branch_id")
        dpt_id=defaults.get("department_id")
        dom=[]
        if ids:
            obj=self.browse(ids)[0]
            date=obj.date
            staff_id=obj.staff_id.id
            staff_type=obj.staff_type
            branch_id=obj.branch_id.id
            dpt_id=obj.department_id.id
        dom.append(['date','>=',date])
        dom.append(['date','<=',date])
        # prevent to load more
        if not staff_id:
            print("not staff_id")
            return {}
        if staff_id:
            dom.append(['staff_id','=',staff_id])
        if staff_type:
            dom.append(['type','=',staff_type])
        if branch_id:
            dom.append(['labor_cost_id.cycle_item_id.branch_id','=',branch_id])
        if dpt_id:
            dom.append(['labor_cost_id.cycle_item_id.department_id','=',dpt_id])
        print('dom ', dom)
        lines=[]
        no=1
        for line in get_model("clinic.labor.cost.line").search_browse(dom):
            lcost=line.labor_cost_id
            citem=lcost.cycle_item_id
            cycle=citem.cycle_id
            staff=line.staff_id
            dpt=citem.department_id
            amt=line.amount or 0
            if staff_type=='doctor':
                for hdcase in citem.hd_cases:
                    if hdcase.state not in ("waiting_payment","paid"):
                        continue
                    doctor=hdcase.doctor_id
                    pt_type=hdcase.patient_type_id
                    pt=hdcase.patient_id
                    if staff.id==doctor.id:
                        lines.append({
                            'hd_case_number': hdcase.number or '',
                            'hd_case_id': hdcase.id or '',
                            'date': hdcase.date or '',
                            'no': no,
                            'hn': pt.number,
                            'patient_id': pt.id,
                            'patient_name': pt.name or '',
                            'patient_type_name': pt_type.name or '',
                            'amount': amt,
                            'dpt_id': dpt.id,
                            'dpt_name': dpt.name or "",
                            'cycle_name': cycle.name,
                            'cycle_id': cycle.id,
                        })
                        no+=1
            elif staff_type=='nurse':
                print("nurse ")
                for hdcase in citem.hd_cases:
                    if hdcase.state not in ("waiting_payment","paid"):
                        continue
                    doctor=hdcase.doctor_id
                    pt_type=hdcase.patient_type_id
                    pt=hdcase.patient_id
                    lines.append({
                        'no': no,
                        'hdcase_number': hdcase.number,
                        'cycle_item_name': citem.name or '',
                        'cycle_item_id': citem.id,
                        'date': citem.date,
                        'hn': pt.number,
                        'patient_id': pt.id,
                        'patient_type_name': pt_type.name or '',
                        'patient_name': pt.name or '',
                        'dpt_id': dpt.id,
                        'dpt_name': dpt.name or "",
                        'amount': 0,
                        'cycle_name': cycle.name,
                        'cycle_id': cycle.id,
                    })
                    no+=1
            else:
                continue
        data={
            'staff_type': staff_type,
            'date': date,
            'comp_name': comp.name or 0,
            'lines': lines,
            'date': date,
        }
        set_active_company(company_id)
        set_active_user(user_id)
        return data

    def onchange_type(self,context={}):
        data=context['data']
        data['staff_id']=None
        return data

ReportLaborCostDaily.register()
